from distutils.core import setup

setup(
    name='pynmr',
    version='0.0',
    author='Daniel Cosmo Pizetta',
    author_email='daniel.pizetta@usp.br',
    packages=['pynmr'],
    url='http://pypi.python.org/pypi/pynmr/',
    description='PyNMR Framework',
    long_description='PyNMR: To hold this name, because we lost two of them ultim now :)',
)
